@@ -60,10 +60,8 @@ struct GpmControlPrivate
 };
 
 enum {
-	REQUEST,
 	RESUME,
 	SLEEP,
-	SLEEP_FAILURE,
 	LAST_SIGNAL
 };
 
@@ -85,106 +83,6 @@ gpm_control_error_quark (void)
 	return quark;
 }
 
-/**
- * gpm_control_check_foreground_console:
- * @manager: This class instance
- * @action: The action we want to do, e.g. "suspend"
- *
- * Checks if the difference in time between this request for an action, and
- * the last action completing is larger than the timeout set in gconf.
- *
- * Also check for the foreground console if we specified
- * --enable-checkfg on the command line. This is only needed on Debian.
- *
- * Return value: TRUE if we can perform the action.
- **/
-static gboolean
-gpm_control_check_foreground_console (GpmControl *control)
-{
-#ifdef HAVE_CHECK_FG
-	gchar *argv[] = { "check-foreground-console", NULL };
-	int retcode;
-
-	if (!g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL,
-				 NULL, NULL, &retcode, NULL)  || ! WIFEXITED (retcode)) {
-		/* if check-foreground-console could not be executed,
-		 * assume active console */
-		egg_debug ("could not execute check-foreground-console");
-		return TRUE;
-	}
-	egg_debug ("check-foreground-console returned with %i", WEXITSTATUS (retcode));
-	return WEXITSTATUS (retcode) == 0;
-#endif
-	/* no other checks failed, so return okay */
-	return TRUE;
-}
-
-/**
- * gpm_control_allowed_suspend:
- * @control: This class instance
- * @can: If we can suspend
- *
- * checks gconf to see if we are allowed to suspend this computer.
- **/
-gboolean
-gpm_control_allowed_suspend (GpmControl *control, gboolean *can, GError **error)
-{
-	gboolean conf_ok;
-	gboolean hardware_ok;
-	gboolean fg;
-	g_return_val_if_fail (can, FALSE);
-
-	*can = FALSE;
-
-	/* get values from DkpClient */
-	g_object_get (control->priv->client,
-		      "can-suspend", &hardware_ok,
-		      NULL);
-
-	conf_ok = gconf_client_get_bool (control->priv->conf, GPM_CONF_CAN_SUSPEND, NULL);
-	g_object_get (control->priv->client,
-		      "can-suspend", &hardware_ok,
-		      NULL);
-	fg = gpm_control_check_foreground_console (control);
-	if (conf_ok && hardware_ok && fg)
-		*can = TRUE;
-	egg_debug ("conf=%i, fg=%i, can=%i", conf_ok, fg, *can);
-	return TRUE;
-}
-
-/**
- * gpm_control_allowed_hibernate:
- * @control: This class instance
- * @can: If we can hibernate
- *
- * Checks the HAL key power_management.can_suspend_to_disk and also
- * checks gconf to see if we are allowed to hibernate this computer.
- **/
-gboolean
-gpm_control_allowed_hibernate (GpmControl *control, gboolean *can, GError **error)
-{
-	gboolean conf_ok;
-	gboolean hardware_ok;
-	gboolean fg;
-	g_return_val_if_fail (can, FALSE);
-
-	/* get values from DkpClient */
-	g_object_get (control->priv->client,
-		      "can-hibernate", &hardware_ok,
-		      NULL);
-
-	*can = FALSE;
-	conf_ok = gconf_client_get_bool (control->priv->conf, GPM_CONF_CAN_HIBERNATE, NULL);
-	fg = gpm_control_check_foreground_console (control);
-	g_object_get (control->priv->client,
-		      "can-hibernate", &hardware_ok,
-		      NULL);
-	if (conf_ok && hardware_ok && fg)
-		*can = TRUE;
-	egg_debug ("conf=%i, fg=%i, can=%i", conf_ok, fg, *can);
-	return TRUE;
-}
-
 /**
  * gpm_control_shutdown:
  * @control: This class instance
@@ -239,7 +137,7 @@ gboolean
 gpm_control_suspend (GpmControl *control, GError **error)
 {
 	gboolean allowed;
-	gboolean ret = FALSE;
+	gboolean ret;
 	gboolean do_lock;
 	gboolean nm_sleep;
 	gboolean lock_gnome_keyring;
@@ -249,15 +147,14 @@ gpm_control_suspend (GpmControl *control, GError **error)
 
 	screensaver = gpm_screensaver_new ();
 
-	gpm_control_allowed_suspend (control, &allowed, error);
-	if (allowed == FALSE) {
+	g_object_get (control->priv->client,
+		      "can-suspend", &allowed,
+		      NULL);
+	if (!allowed) {
 		egg_debug ("cannot suspend as not allowed from policy");
-		g_set_error (error,
-			     GPM_CONTROL_ERROR,
-			     GPM_CONTROL_ERROR_GENERAL,
-			     "Cannot suspend as not allowed from policy");
-		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_SUSPEND);
-		return FALSE;
+		if (error != NULL)
+			*error = g_error_new (GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot suspend");
+		goto out;
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
@@ -287,11 +184,6 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
 
-	if (!ret) {
-		egg_debug ("emitting sleep-failure");
-		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_SUSPEND);
-	}
-
 	if (do_lock) {
 		gpm_screensaver_poke (screensaver);
 		if (throttle_cookie)
@@ -302,8 +194,8 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	if (nm_sleep)
 		gpm_networkmanager_wake ();
 
+out:
 	g_object_unref (screensaver);
-
 	return ret;
 }
 
@@ -314,7 +206,7 @@ gboolean
 gpm_control_hibernate (GpmControl *control, GError **error)
 {
 	gboolean allowed;
-	gboolean ret;
+	gboolean ret = FALSE;
 	gboolean do_lock;
 	gboolean nm_sleep;
 	gboolean lock_gnome_keyring;
@@ -324,16 +216,14 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 
 	screensaver = gpm_screensaver_new ();
 
-	gpm_control_allowed_hibernate (control, &allowed, error);
-
-	if (allowed == FALSE) {
+	g_object_get (control->priv->client,
+		      "can-hibernate", &allowed,
+		      NULL);
+	if (!allowed) {
 		egg_debug ("cannot hibernate as not allowed from policy");
-		g_set_error (error,
-			     GPM_CONTROL_ERROR,
-			     GPM_CONTROL_ERROR_GENERAL,
-			     "Cannot hibernate");
-		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_HIBERNATE);
-		return FALSE;
+		if (error != NULL)
+			*error = g_error_new (GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot hibernate");
+		goto out;
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
@@ -363,11 +253,6 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
-	if (!ret) {
-		egg_debug ("emitting sleep-failure");
-		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_HIBERNATE);
-	}
-
 	if (do_lock) {
 		gpm_screensaver_poke (screensaver);
 		if (throttle_cookie)
@@ -378,8 +263,8 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	if (nm_sleep)
 		gpm_networkmanager_wake ();
 
+out:
 	g_object_unref (screensaver);
-
 	return ret;
 }
 
@@ -429,24 +314,6 @@ gpm_control_class_init (GpmControlClass *klass)
 			      NULL,
 			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
-	signals [SLEEP_FAILURE] =
-		g_signal_new ("sleep-failure",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmControlClass, sleep_failure),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__INT,
-			      G_TYPE_NONE, 1, G_TYPE_INT);
-	signals [REQUEST] =
-		g_signal_new ("request",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmControlClass, request),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__STRING,
-			      G_TYPE_NONE, 1, G_TYPE_STRING);
 
 	g_type_class_add_private (klass, sizeof (GpmControlPrivate));
 }
